WebTreeApplication object — ETE Toolkit - analysis and visualization of trees

New in version 2.1.

# WebTreeApplication object

class `WebTreeApplication`

  Provides a basic WSGI application object which can handle ETE tree visualization and interactions. Please, see the webplugin example provided with the ETE installation package (http://pypi.python.org/pypi/ete3).

  `register_action`(name, target, handler, checker, html_generator)

    Adds a new web interactive function associated to tree nodes.

  `set_default_layout_fn`(layout_fn)

    Fix the layout function used to render the tree.

  `set_external_app_handler`(handler)

    Sets a custom function that will extend current WSGI application.

  `set_external_tree_renderer`(handler)

    If the tree needs to be processed every time is going to be drawn, the task can be delegated.

  `set_tree_loader`(TreeConstructor)

    Delegate tree constructor. It allows to customize the Tree class used to create new tree instances.

  `set_tree_size`(w, h, units='px')

    Fix the size of tree image

  `set_tree_style`(handler)

    Fix a `TreeStyle` instance to render tree images.